@@ -18,6 +18,7 @@ greenFlag = False
 processed = False
 reqs = 0
 chars = 0
+
 enUi = ['button', 'checkbox', 'field', 'column', 'area', 'box', 'role', 'user', 'line', 'table', 'mode', 'module', 'menu', 'event',
         'RFx', 'search', 'page', 'tab', 'panel', 'option', 'dialog', 'status', 'tag', 'symbol', 'sign', 'label', 'scenario', 'link',
         'auction', 'events', 'checkboxes', 'columns', 'lines', 'answers', 'answer', 'responses', 'response', 'buttons', 'fields',
@@ -25,29 +26,14 @@ enUi = ['button', 'checkbox', 'field', 'column', 'area', 'box', 'role', 'user',
         'modal windows', 'dialog window', 'dialog windows', 'homepage', 'folder', 'folders', 'file', 'files', 'project', 'projects',
         'image', 'images']
 
-# Configuração da API de tradução
-
 urlTrad = 'https://translate.yandex.net/api/v1.5/tr.json/translate'
 apiTradKey = ''
-
-# Idioma fonte
-
 sourceLang = ''
-
-# Idiomas traduzidos
-
 targetLangs = []
-
-# Diretório fonte
-
 sourceDir = ''
-
-# Configurações
-
+haltedTranslation=[]
 configs = {}
 
-# Preservação da sintaxe Markdown DocFX
-
 mdRegex = re.compile(r'''(\]\(.+?\)[\W ]?)|          # referência de imagem ou link
                          (uid:\s?[\w.]+)|            # âncora de link no cabeçalho
                          (\{\{.*?\}\}[\W ]+?)|       # nome de elemento de UI
@@ -58,8 +44,6 @@ mdRegex = re.compile(r'''(\]\(.+?\)[\W ]?)|          # referência de imagem ou
                          (\s*?\d\.\s)|               # numeração em lista numerada
                          (\s?[\[!#*|>\r\n\t]+?\s*)   # outros elementos de Markdown DocFX''', re.VERBOSE | re.DOTALL)
 
-# Preservação da sintaxe Yaml DocFX
-
 ymlRegex = re.compile(r'(name: [ \w\'\-]+)')         # traduz texto entre 'name: ' e quebra de linha
 
 #--------------------------------
@@ -127,6 +111,8 @@ def ProcessFiles(sourceFile):
                 file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
                 file.write(targetContent)
                 file.close()
+            else:
+                haltedTranslation.append(sourceFile)
         return
     PrLightPurple('Copying "' + sourceFile + '"')
     for i in range (len(targetLangs)):
@@ -166,7 +152,7 @@ def Translate(text, langCombo):
                 'lang': langCombo,
                 'text': text
                 },
-            timeout = 1.2
+            timeout = 1
         )
     except requests.Timeout:
         PrYellow('A request timed out!')
@@ -320,10 +306,15 @@ def diff():
                             os.remove(path + '/' + '/'.join(doc.split('/')[1:]))
                         except:
                             pass
-            PrGreen('\n Completed successfully!')
+            if not len(haltedTranslation):
+                PrGreen('\n Completed successfully!')
+            else:
+                PrYellow("The following files could neither be processed nor copied to target language directories:")
+                for notTranslated in haltedTranslation:
+                    print(' ' + notTranslated)
     else:
         PrYellow('There have been no changes to the source language directory since the last commit.')
-    if cont != 'c': PrRed('\n Exiting...')
+    if cont != 'c' or len(haltedTranslation): PrRed('\n Exiting...')
     time.sleep(1)
     re.purge
     exit()
@@ -417,9 +408,13 @@ def all():
                 greenFlag = True
             else:
                 break
-    if greenFlag:
+    if greenFlag and not len(haltedTranslation):
         PrGreen('\n Completed successfully!')
     else:
+        if greenFlag:
+            PrYellow("The following files could neither be processed nor copied to target language directories:")
+            for notTranslated in haltedTranslation:
+                print(' ' + notTranslated)
         PrRed('\n Exiting...')
     time.sleep(1)
     re.purge()
